@@ -27,5 +27,5 @@ def run_pred_step(test_loader, model, x_cat=None, target=False):
             pred = model(x, x_cat).to(device).detach().numpy()
         # pred_list.append(pred.squeeze())
 
-    return pred
+    return pred.squeeze()
             
\ No newline at end of file
