@@ -124,7 +124,8 @@ def dataloader_by_stock(
     batch_size=32,  
     continous_cols=['Close'],
     return_scaler=False,
-    transform=StandardScaler
+    transform=StandardScaler, 
+    train_size=0.85
     ):
     df = train_df[train_df['SecuritiesCode'] == sec_code].drop(['SecuritiesCode'], axis=1)
     df = date_features(df)
@@ -142,9 +143,9 @@ def dataloader_by_stock(
     
     # print('continuos shape:', cont.shape, '', 'categorical shape:', cat.shape)
     
-    df_train_cat, df_val_cat = ts_split(cat)
+    df_train_cat, df_val_cat = ts_split(cat, train_size)
     # print('cat_columns:', df_train_cat.columns)
-    df_train, df_val = ts_split(cont)
+    df_train, df_val = ts_split(cont, train_size)
 
     xtrain, ytrain = preprocess(df_train, 'Target', 1, continous_cols=continous_cols)
     xval, yval = preprocess(df_val, 'Target', 1, continous_cols=continous_cols)
@@ -199,12 +200,11 @@ def dataloader_test_by_stock(
     # print('continuos shape:', cont.shape, '', 'categorical shape:', cat.shape)
     xtest, idx = preprocess(cont, target_col, 1, continous_cols=continous_cols, return_idx=return_idx)
 
-    if len(xtest) == 1:
-        xtest = xtest.reshape(1, -1)
-    if transformer is not None:
-        xtest = transformer.transform(xtest)
-    # else:
-    #     print('Notice that the transformer is None.')
+    if len(xtest) > 0:
+        if len(xtest) == 1:
+            xtest = xtest.reshape(1, -1)
+        if transformer is not None:
+            xtest = transformer.transform(xtest)
 
     test_dataloader = get_predict_loader(
         x=xtest, 
@@ -216,11 +216,11 @@ def dataloader_test_by_stock(
     return test_dataloader
 
 
-def ts_split(raw_data, train_size=0.85, val_size=None):
+def ts_split(raw_data, train_size=0.85):
     """
     Hard code and train date.
     """
-    train_sz = '2021-11-30' #int(len(raw_data) * train_size)
+    train_sz = int(len(raw_data) * train_size) #'2021-11-30' #int(len(raw_data) * train_size)
     train_set = raw_data[ :train_sz]
     valid_set = raw_data[train_sz: ]
     return train_set, valid_set    
